@@ -28,9 +28,9 @@
  *    original.  Also, there is now a builtin-test, just compile with:
  *           gcc -DTEST_SNPRINTF -o snprintf snprintf.c -lm
  *    and run snprintf for results.
- * 
+ *
  *  Thomas Roessler <roessler@does-not-exist.org> 01/27/98 for mutt 0.89i
- *    The PGP code was using unsigned hexadecimal formats. 
+ *    The PGP code was using unsigned hexadecimal formats.
  *    Unfortunately, unsigned formats simply didn't work.
  *
  *  Michael Elkins <me@mutt.org> 03/05/98 for mutt 0.90.8
@@ -86,7 +86,7 @@
 /*int snprintf (char *str, size_t count, const char *fmt, ...);*/
 /*int vsnprintf (char *str, size_t count, const char *fmt, va_list arg);*/
 
-static int dopr (char *buffer, size_t maxlen, const char *format, 
+static int dopr (char *buffer, size_t maxlen, const char *format,
                   va_list args);
 static void fmtstr (char *buffer, size_t *currlen, size_t maxlen,
 		    char *value, int flags, int min, int max);
@@ -141,7 +141,7 @@ static int dopr (char *buffer, size_t maxlen, const char *format, va_list args)
   int flags;
   int cflags;
   size_t currlen;
-  
+
   state = DP_S_DEFAULT;
   currlen = flags = cflags = min = 0;
   max = -1;
@@ -152,17 +152,17 @@ static int dopr (char *buffer, size_t maxlen, const char *format, va_list args)
     if (ch == '\0')
       state = DP_S_DONE;
 
-    switch(state) 
+    switch (state)
     {
     case DP_S_DEFAULT:
-      if (ch == '%') 
+      if (ch == '%')
 	state = DP_S_FLAGS;
-      else 
+      else
 	dopr_outch (buffer, &currlen, maxlen, ch);
       ch = *format++;
       break;
     case DP_S_FLAGS:
-      switch (ch) 
+      switch (ch)
       {
       case '-':
 	flags |= DP_F_MINUS;
@@ -190,48 +190,48 @@ static int dopr (char *buffer, size_t maxlen, const char *format, va_list args)
       }
       break;
     case DP_S_MIN:
-      if (isdigit((unsigned char)ch)) 
+      if (isdigit((unsigned char)ch))
       {
 	min = 10*min + char_to_int (ch);
 	ch = *format++;
-      } 
-      else if (ch == '*') 
+      }
+      else if (ch == '*')
       {
 	min = va_arg (args, int);
 	ch = *format++;
 	state = DP_S_DOT;
-      } 
-      else 
+      }
+      else
 	state = DP_S_DOT;
       break;
     case DP_S_DOT:
-      if (ch == '.') 
+      if (ch == '.')
       {
 	state = DP_S_MAX;
 	ch = *format++;
-      } 
-      else 
+      }
+      else
 	state = DP_S_MOD;
       break;
     case DP_S_MAX:
-      if (isdigit((unsigned char)ch)) 
+      if (isdigit((unsigned char)ch))
       {
 	if (max < 0)
 	  max = 0;
 	max = 10*max + char_to_int (ch);
 	ch = *format++;
-      } 
-      else if (ch == '*') 
+      }
+      else if (ch == '*')
       {
 	max = va_arg (args, int);
 	ch = *format++;
 	state = DP_S_MOD;
-      } 
-      else 
+      }
+      else
 	state = DP_S_MOD;
       break;
     case DP_S_MOD:
-      switch (ch) 
+      switch (ch)
       {
       case 'h':
 	cflags = DP_C_SHORT;
@@ -256,11 +256,11 @@ static int dopr (char *buffer, size_t maxlen, const char *format, va_list args)
       state = DP_S_CONV;
       break;
     case DP_S_CONV:
-      switch (ch) 
+      switch (ch)
       {
       case 'd':
       case 'i':
-	if (cflags == DP_C_SHORT) 
+	if (cflags == DP_C_SHORT)
 	  value = va_arg (args, short int);
 	else if (cflags == DP_C_LONG)
 	  value = va_arg (args, long int);
@@ -345,25 +345,25 @@ static int dopr (char *buffer, size_t maxlen, const char *format, va_list args)
 	fmtint (buffer, &currlen, maxlen, (long) strvalue, 16, min, max, flags);
 	break;
       case 'n':
-	if (cflags == DP_C_SHORT) 
+	if (cflags == DP_C_SHORT)
 	{
 	  short int *num;
 	  num = va_arg (args, short int *);
 	  *num = currlen;
-        } 
-	else if (cflags == DP_C_LONG) 
+        }
+	else if (cflags == DP_C_LONG)
 	{
 	  long int *num;
 	  num = va_arg (args, long int *);
 	  *num = currlen;
-        } 
-	else if (cflags == DP_C_LONGLONG) 
+        }
+	else if (cflags == DP_C_LONGLONG)
 	{
 	  long long int *num;
 	  num = va_arg (args, long long int *);
 	  *num = currlen;
-        } 
-	else 
+        }
+	else
 	{
 	  int *num;
 	  num = va_arg (args, int *);
@@ -393,9 +393,9 @@ static int dopr (char *buffer, size_t maxlen, const char *format, va_list args)
       break; /* some picky compilers need this */
     }
   }
-  if (currlen < maxlen - 1) 
+  if (currlen < maxlen - 1)
     buffer[currlen] = '\0';
-  else 
+  else
     buffer[maxlen - 1] = '\0';
 
   return (int)currlen;
@@ -406,7 +406,7 @@ static void fmtstr (char *buffer, size_t *currlen, size_t maxlen,
 {
   int padlen, strln;     /* amount to pad */
   int cnt = 0;
-  
+
   if (!value)
   {
     value = "<NULL>";
@@ -414,23 +414,23 @@ static void fmtstr (char *buffer, size_t *currlen, size_t maxlen,
 
   for (strln = 0; value[strln]; ++strln); /* strlen */
   padlen = min - strln;
-  if (padlen < 0) 
+  if (padlen < 0)
     padlen = 0;
-  if (flags & DP_F_MINUS) 
+  if (flags & DP_F_MINUS)
     padlen = -padlen; /* Left Justify */
 
-  while ((padlen > 0) && (max == -1 || cnt < max)) 
+  while ((padlen > 0) && (max == -1 || cnt < max))
   {
     dopr_outch (buffer, currlen, maxlen, ' ');
     --padlen;
     ++cnt;
   }
-  while (*value && (max == -1 || cnt < max)) 
+  while (*value && (max == -1 || cnt < max))
   {
     dopr_outch (buffer, currlen, maxlen, *value++);
     ++cnt;
   }
-  while ((padlen < 0) && (max == -1 || cnt < max)) 
+  while ((padlen < 0) && (max == -1 || cnt < max))
   {
     dopr_outch (buffer, currlen, maxlen, ' ');
     ++padlen;
@@ -450,15 +450,16 @@ static void fmtint (char *buffer, size_t *currlen, size_t maxlen,
   int spadlen = 0; /* amount to space pad */
   int zpadlen = 0; /* amount to zero pad */
   int caps = 0;
-  
+
   if (max < 0)
     max = 0;
 
   uvalue = value;
 
-  if(!(flags & DP_F_UNSIGNED))
+  if (!(flags & DP_F_UNSIGNED))
   {
-    if( value < 0 ) {
+    if ( value < 0 )
+    {
       signvalue = '-';
       uvalue = -value;
     }
@@ -469,15 +470,16 @@ static void fmtint (char *buffer, size_t *currlen, size_t maxlen,
       if (flags & DP_F_SPACE)
 	signvalue = ' ';
   }
-  
+
   if (flags & DP_F_UP) caps = 1; /* Should characters be upper case? */
 
-  do {
+  do
+  {
     convert[place++] =
       (caps? "0123456789ABCDEF":"0123456789abcdef")
       [uvalue % (unsigned)base  ];
     uvalue = (uvalue / (unsigned)base );
-  } while(uvalue && (place < 20));
+  } while (uvalue && (place < 20));
   if (place == 20) place--;
   convert[place] = 0;
 
@@ -490,7 +492,7 @@ static void fmtint (char *buffer, size_t *currlen, size_t maxlen,
     zpadlen = MAX(zpadlen, spadlen);
     spadlen = 0;
   }
-  if (flags & DP_F_MINUS) 
+  if (flags & DP_F_MINUS)
     spadlen = -spadlen; /* Left Justifty */
 
 #ifdef DEBUG_SNPRINTF
@@ -499,18 +501,18 @@ static void fmtint (char *buffer, size_t *currlen, size_t maxlen,
 #endif
 
   /* Spaces */
-  while (spadlen > 0) 
+  while (spadlen > 0)
   {
     dopr_outch (buffer, currlen, maxlen, ' ');
     --spadlen;
   }
 
   /* Sign */
-  if (signvalue) 
+  if (signvalue)
     dopr_outch (buffer, currlen, maxlen, signvalue);
 
   /* Zeros */
-  if (zpadlen > 0) 
+  if (zpadlen > 0)
   {
     while (zpadlen > 0)
     {
@@ -520,11 +522,12 @@ static void fmtint (char *buffer, size_t *currlen, size_t maxlen,
   }
 
   /* Digits */
-  while (place > 0) 
+  while (place > 0)
     dopr_outch (buffer, currlen, maxlen, convert[--place]);
-  
+
   /* Left Justified spaces */
-  while (spadlen < 0) {
+  while (spadlen < 0)
+  {
     dopr_outch (buffer, currlen, maxlen, ' ');
     ++spadlen;
   }
@@ -549,7 +552,7 @@ static long double pow10 (int exp)
     result *= 10;
     exp--;
   }
-  
+
   return result;
 }
 
@@ -575,12 +578,12 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
   int iplace = 0;
   int fplace = 0;
   int padlen = 0; /* amount to pad */
-  int zpadlen = 0; 
+  int zpadlen = 0;
   int caps = 0;
   long intpart;
   long fracpart;
-  
-  /* 
+
+  /*
    * AIX manpage says the default is 0, but Solaris says the default
    * is 6, and sprintf on AIX defaults to 6
    */
@@ -604,8 +607,8 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
 
   intpart = ufvalue;
 
-  /* 
-   * Sorry, we only support 9 digits past the decimal because of our 
+  /*
+   * Sorry, we only support 9 digits past the decimal because of our
    * conversion method
    */
   if (max > 9)
@@ -627,36 +630,38 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
 #endif
 
   /* Convert integer part */
-  do {
+  do
+  {
     iconvert[iplace++] =
       (caps? "0123456789ABCDEF":"0123456789abcdef")[intpart % 10];
     intpart = (intpart / 10);
-  } while(intpart && (iplace < 20));
+  } while (intpart && (iplace < 20));
   if (iplace == 20) iplace--;
   iconvert[iplace] = 0;
 
   /* Convert fractional part */
-  do {
+  do
+  {
     fconvert[fplace++] =
       (caps? "0123456789ABCDEF":"0123456789abcdef")[fracpart % 10];
     fracpart = (fracpart / 10);
-  } while(fracpart && (fplace < 20));
+  } while (fracpart && (fplace < 20));
   if (fplace == 20) fplace--;
   fconvert[fplace] = 0;
 
   /* -1 for decimal point, another -1 if we are printing a sign */
-  padlen = min - iplace - max - 1 - ((signvalue) ? 1 : 0); 
+  padlen = min - iplace - max - 1 - ((signvalue) ? 1 : 0);
   zpadlen = max - fplace;
   if (zpadlen < 0)
     zpadlen = 0;
-  if (padlen < 0) 
+  if (padlen < 0)
     padlen = 0;
-  if (flags & DP_F_MINUS) 
+  if (flags & DP_F_MINUS)
     padlen = -padlen; /* Left Justifty */
 
-  if ((flags & DP_F_ZERO) && (padlen > 0)) 
+  if ((flags & DP_F_ZERO) && (padlen > 0))
   {
-    if (signvalue) 
+    if (signvalue)
     {
       dopr_outch (buffer, currlen, maxlen, signvalue);
       --padlen;
@@ -673,10 +678,10 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
     dopr_outch (buffer, currlen, maxlen, ' ');
     --padlen;
   }
-  if (signvalue) 
+  if (signvalue)
     dopr_outch (buffer, currlen, maxlen, signvalue);
 
-  while (iplace > 0) 
+  while (iplace > 0)
     dopr_outch (buffer, currlen, maxlen, iconvert[--iplace]);
 
   /*
@@ -685,7 +690,7 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
    */
   dopr_outch (buffer, currlen, maxlen, '.');
 
-  while (fplace > 0) 
+  while (fplace > 0)
     dopr_outch (buffer, currlen, maxlen, fconvert[--fplace]);
 
   while (zpadlen > 0)
@@ -694,7 +699,7 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
     --zpadlen;
   }
 
-  while (padlen < 0) 
+  while (padlen < 0)
   {
     dopr_outch (buffer, currlen, maxlen, ' ');
     ++padlen;
@@ -732,7 +737,7 @@ int snprintf (va_alist) va_dcl
 #endif
   int len;
   VA_LOCAL_DECL;
-    
+
   VA_START (fmt);
   VA_SHIFT (str, char *);
   VA_SHIFT (count, size_t );
@@ -764,7 +769,7 @@ int main (void)
     "%3.2f",
     NULL
   };
-  double fp_nums[] = { -1.5, 134.21, 91340.2, 341.1234, 0203.9, 0.96, 0.996, 
+  double fp_nums[] = { -1.5, 134.21, 91340.2, 341.1234, 0203.9, 0.96, 0.996,
     0.9996, 1.996, 4.136, 0};
   char *int_fmt[] = {
     "%-1.5d",
